@@ -21,22 +21,8 @@
 //! }
 //! ```
 
-#[macro_use]
-extern crate error_chain;
-extern crate hmac;
-extern crate libc;
-extern crate nix;
-extern crate serde;
-#[macro_use]
-extern crate serde_derive;
-extern crate sha2;
-#[macro_use]
-extern crate try_or;
-extern crate uuid;
-
-#[cfg(test)]
-#[macro_use]
-extern crate quickcheck;
+/// Interfaces for socket-activated services.
+pub mod activation;
 
 /// Interfaces for systemd-aware daemons.
 pub mod daemon;
@@ -44,6 +30,9 @@ pub mod daemon;
 /// Error handling.
 pub mod errors;
 
+/// Helpers for logging to systemd-journald.
+pub mod logging;
+
 /// Helpers for working with systemd units.
 pub mod unit;
 
